Struct ratatui_block::block_grid::BlockGrid
source · pub struct BlockGrid { /* private fields */ }Expand description
Renders a block border and a connected grid inside.
Implementations
sourceimpl BlockGrid
impl BlockGrid
pub fn new() -> Self
sourcepub fn from_layout(layout: &[Rect]) -> Self
pub fn from_layout(layout: &[Rect]) -> Self
Create a grid line for every single cell gap between the given areas.
If the areas overlap, or if they have overlapping x- or y-ranges the results may not be what you expect.
sourcepub fn border_style(self, style: Style) -> Self
pub fn border_style(self, style: Style) -> Self
Border style for the border.
sourcepub fn border_type(self, border_type: BorderType) -> Self
pub fn border_type(self, border_type: BorderType) -> Self
Border style for the border.
sourcepub fn border_set(self, border_set: impl BorderSymbolSet + 'static) -> Self
pub fn border_set(self, border_set: impl BorderSymbolSet + 'static) -> Self
Border style for the border.
sourcepub fn horizontal_style(self, style: Style) -> Self
pub fn horizontal_style(self, style: Style) -> Self
Border style for the border.
sourcepub fn horizontal_side(self, side: Side) -> Self
pub fn horizontal_side(self, side: Side) -> Self
Add a horizontal side.
sourcepub fn horizontal_border_type(self, border: BorderType) -> Self
pub fn horizontal_border_type(self, border: BorderType) -> Self
Sets the border type used.
sourcepub fn horizontal_border_set(
self,
border_set: impl BorderSymbolSet + 'static,
) -> Self
pub fn horizontal_border_set( self, border_set: impl BorderSymbolSet + 'static, ) -> Self
Use a BorderSymbolSet.
sourcepub fn horizontal(self, pos: u16) -> Self
pub fn horizontal(self, pos: u16) -> Self
Add a horizontal divider.
sourcepub fn vertical_style(self, style: Style) -> Self
pub fn vertical_style(self, style: Style) -> Self
Border style for the border.
sourcepub fn vertical_side(self, side: Side) -> Self
pub fn vertical_side(self, side: Side) -> Self
Add a vertical side.
sourcepub fn vertical_border_type(self, border: BorderType) -> Self
pub fn vertical_border_type(self, border: BorderType) -> Self
Sets the border type used.
sourcepub fn vertical_border_set(
self,
border_set: impl BorderSymbolSet + 'static,
) -> Self
pub fn vertical_border_set( self, border_set: impl BorderSymbolSet + 'static, ) -> Self
Use a BorderSymbolSet.