Struct ratatui_block::border_symbols::StaticSymbolSet

source ·
pub struct StaticSymbolSet {
Show 38 fields pub similar_to: BorderType, pub top_left_regular: &'static str, pub top_left_angled: &'static str, pub top_left_prolonged: &'static str, pub top_left_crossed: &'static str, pub top_regular: &'static str, pub top_overlap: &'static str, pub top_outward: &'static str, pub top_inward: &'static str, pub top_crossed: &'static str, pub top_right_regular: &'static str, pub top_right_angled: &'static str, pub top_right_prolonged: &'static str, pub top_right_crossed: &'static str, pub bottom_left_regular: &'static str, pub bottom_left_angled: &'static str, pub bottom_left_prolonged: &'static str, pub bottom_left_crossed: &'static str, pub bottom_regular: &'static str, pub bottom_overlap: &'static str, pub bottom_outward: &'static str, pub bottom_inward: &'static str, pub bottom_crossed: &'static str, pub bottom_right_regular: &'static str, pub bottom_right_angled: &'static str, pub bottom_right_prolonged: &'static str, pub bottom_right_crossed: &'static str, pub left_regular: &'static str, pub left_overlap: &'static str, pub left_outward: &'static str, pub left_inward: &'static str, pub left_crossed: &'static str, pub right_regular: &'static str, pub right_overlap: &'static str, pub right_outward: &'static str, pub right_inward: &'static str, pub right_crossed: &'static str, pub crossed: &'static str,
}
For manual borders.

This symbol set can have connections to other borders, but it’s not possible to have different connections depending on the other border.

Fields

similar_to: BorderType

When connecting to other borders, how does this one behave like?

top_left_regular: &'static strtop_left_angled: &'static strtop_left_prolonged: &'static strtop_left_crossed: &'static strtop_regular: &'static strtop_overlap: &'static strtop_outward: &'static strtop_inward: &'static strtop_crossed: &'static strtop_right_regular: &'static strtop_right_angled: &'static strtop_right_prolonged: &'static strtop_right_crossed: &'static strbottom_left_regular: &'static strbottom_left_angled: &'static strbottom_left_prolonged: &'static strbottom_left_crossed: &'static strbottom_regular: &'static strbottom_overlap: &'static strbottom_outward: &'static strbottom_inward: &'static strbottom_crossed: &'static strbottom_right_regular: &'static strbottom_right_angled: &'static strbottom_right_prolonged: &'static strbottom_right_crossed: &'static strleft_regular: &'static strleft_overlap: &'static strleft_outward: &'static strleft_inward: &'static strleft_crossed: &'static strright_regular: &'static strright_overlap: &'static strright_outward: &'static strright_inward: &'static strright_crossed: &'static strcrossed: &'static str