Trait ratatui_block::BorderSymbolSet

source ·
pub trait BorderSymbolSet: DynClone {
    // Required methods
    fn border_type(&self) -> BorderType;
    fn symbol(&self, side: Side, symbol: BorderSymbol) -> &'static str;
    fn crossing(
        &self,
        top_side: Side,
        top: BorderType,
        right_side: Side,
        right: BorderType,
        bottom_side: Side,
        bottom: BorderType,
        left_side: Side,
        left: BorderType,
    ) -> &'static str;
}
Symbol set trait

Required Methods

source

fn border_type(&self) -> BorderType

Equivalent BorderType.

source

fn symbol(&self, side: Side, symbol: BorderSymbol) -> &'static str

Get the actual symbol occurring along one side of the area.

side: Which side of the area. symbol: Symbol definition.

source

fn crossing( &self, top_side: Side, top: BorderType, right_side: Side, right: BorderType, bottom_side: Side, bottom: BorderType, left_side: Side, left: BorderType, ) -> &'static str

Get the symbol for a 4-way crossing of lines.

The number of parameters comes from handling Quadrant crossings. schematics

Remark Not needed for drawing Rects or grids, but a bit of a missing link otherwise.

Implementors