Trait ratatui_block::BorderSymbolSet
source · pub trait BorderSymbolSet: DynClone {
// Required methods
fn border_type(&self) -> BorderType;
fn symbol(&self, side: Side, symbol: BorderSymbol) -> &'static str;
fn crossing(
&self,
top_side: Side,
top: BorderType,
right_side: Side,
right: BorderType,
bottom_side: Side,
bottom: BorderType,
left_side: Side,
left: BorderType,
) -> &'static str;
}Expand description
Symbol set trait
Required Methods
sourcefn border_type(&self) -> BorderType
fn border_type(&self) -> BorderType
Equivalent BorderType.
sourcefn symbol(&self, side: Side, symbol: BorderSymbol) -> &'static str
fn symbol(&self, side: Side, symbol: BorderSymbol) -> &'static str
Get the actual symbol occurring along one side of the area.
side: Which side of the area. symbol: Symbol definition.
sourcefn crossing(
&self,
top_side: Side,
top: BorderType,
right_side: Side,
right: BorderType,
bottom_side: Side,
bottom: BorderType,
left_side: Side,
left: BorderType,
) -> &'static str
fn crossing( &self, top_side: Side, top: BorderType, right_side: Side, right: BorderType, bottom_side: Side, bottom: BorderType, left_side: Side, left: BorderType, ) -> &'static str
Get the symbol for a 4-way crossing of lines.
The number of parameters comes from handling Quadrant crossings.

Remark Not needed for drawing Rects or grids, but a bit of a missing link otherwise.